@@ -9,15 +9,15 @@ En::Latn - Package for language En
 package Locale::CLDR::Locales::En::Latn;
 
 # This file auto generated
-#	on Sun 25 Feb 10:41:40 am GMT
+#	on Fri 17 Jan 12:03:31 pm GMT
 
 use version;
 
-our $VERSION = version->declare('v0.44.0');
+our $VERSION = version->declare('v0.46.0');
 
-use v5.10.1;
+use v5.12.0;
 use mro 'c3';
-use if $^V ge v5.12.0, feature => 'unicode_strings';
+use feature 'unicode_strings';
 
 use Moo;
 
